#
# spec file for package xsane
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} <= 1600
%bcond_without gimp
%else
%bcond_with gimp
%endif

Name:           xsane
Version:        0.999
Release:        6.1
Summary:        A GTK-Based Graphical Scanning Front-End for SANE
License:        GPL-2.0-or-later
Group:          Hardware/Scanner
URL:            http://www.xsane.org/
# URL for Source0: http://www.xsane.org/download/xsane-0.998.tar.gz
Source0:        http://www.xsane.org/download/xsane-%{version}.tar.gz
Patch0:         xsane-memory-leak.diff
Patch1:         xsane-libpng15.patch
Patch2:         xsane-0.999-lcms2.patch
Patch3:         001-xdg-open-as-default-browser.patch
Patch4:         002-close-fds.patch
Patch5:         004-ipv6-support.patch
Patch7:         006-preview-selection.patch
Patch8:         100-remove-non-working-help.patch
Patch9:         101-xsane_fix_pdf_floats.patch
Patch10:        200-fix_options_handling_fix.patch
Patch11:        201-fix_pdf_xref.patch
Patch12:        901-desktop-file.patch
Patch13:        902-license-dialog.patch
Patch14:        903-fix_broken_links.patch
Patch18:        907-fix_spin_button_pagesize.patch
Patch19:        908-no-file-selected.patch
Patch20:        0010-fix_missing_sane-config.patch
Patch21:        0005-m4.patch
Patch22:        909-gcc15.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
%if %{with gimp}
BuildRequires:  gimp-devel
%else
BuildRequires:  gtk2-devel
%endif
BuildRequires:  libgphoto2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  sane-backends-devel
BuildRequires:  update-desktop-files
Requires:       sane-backends
Requires:       xdg-utils
Provides:       gimp-2.0-scanner-plugin

%description
XSane does not support any scanners itself. XSane uses the SANE library
to talk to scanners that are supported by SANE.

XSane is designed for acquiring images with scanners (there are other
devices like cameras and video devices supported by SANE, but XSane is
not designed for that purpose). You can scan to file, make a photocopy,
create a fax, and start XSane from the GIMP as a GIMP plug-in.

XSane may not work correctly or you may not be able to take full
advantage of all functions if you do not configure XSane correctly. See
the documentation at %{_datadir}/sane/xsane/doc/sane-xsane-doc.html.

The XSane home page is http://www.xsane.org/.

%prep
%setup -q
# zh is not valid locale. In fact it is zh_TW:
mv po/zh.po po/zh_TW.po
mv po/zh.gmo po/zh_TW.gmo
sed -i "s/ zh / zh_TW /" configure.in configure
%autopatch -p1

mv configure.in configure.ac

%build
# Set our preferred architecture-specific flags for the compiler and linker:
export CFLAGS="%{optflags} -fno-strict-aliasing"
ACLOCAL="aclocal -I m4" autoreconf -f -i
%configure\
%if %{with gimp}
	--enable-gimp
%else
	--disable-gimp
%endif
make %{?_smp_mflags}

%install
%make_install
# Create GIMP plugin link:
mkdir -p %{buildroot}%{_libdir}/gimp/2.0/plug-ins
ln -sf %{_bindir}/xsane %{buildroot}%{_libdir}/gimp/2.0/plug-ins/xsane
%suse_update_desktop_file %{name}
%find_lang %{name}
%fdupes %{buildroot}

%files -f %{name}.lang
%doc xsane.[A-HJ-VX-Z]*
%{_bindir}/xsane
%dir %{_datadir}/sane
%{_datadir}/sane/xsane
%{_mandir}/man1/xsane.1*
%dir %{_libdir}/gimp/
%dir %{_libdir}/gimp/2.0/
%dir %{_libdir}/gimp/2.0/plug-ins/
%{_libdir}/gimp/2.0/plug-ins/*
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.xpm

%changelog
* Thu Feb 13 2025 pgajdos@suse.com
- fix build with gcc 15
- added patches
  + 909-gcc15.patch
* Thu Jan 23 2025 Giacomo Comes <gcomes.obs@gmail.com>
- fix build on tumbleweed
  * disable gimp plugin (gimp3 not supported)
* Sun May 14 2023 Carsten Ziepke <kieltux@gmail.com>
- Rebase 0010-fix_missing_sane-config.patch with
  https://sources.debian.org/patches/xsane/0.999-12/0010-fix_missing_sane-config.patch/
* Wed Mar  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Own %%%%{_datadir}/sane, needed now due to changes elsewhere in the
  stack.
* Fri Jul 21 2017 tchvatal@suse.com
- Rebase patches to include rh/gentoo/debian ones:
  A 001-xdg-open-as-default-browser.patch
  A 002-close-fds.patch
  A 004-ipv6-support.patch
  A 006-preview-selection.patch
  A 100-remove-non-working-help.patch
  A 101-xsane_fix_pdf_floats.patch
  A 200-fix_options_handling_fix.patch
  A 201-fix_pdf_xref.patch
  A 901-desktop-file.patch
  A 902-license-dialog.patch
  A 903-fix_broken_links.patch
  A 904-fix_message_typo.patch
  A 907-fix_spin_button_pagesize.patch
  A 908-no-file-selected.patch
  A 0005-m4.patch
  A 0010-fix_missing_sane-config.patch
- Drop patches hanled in the above:
  D no-eula.patch
  D remove-non-working-help.patch
  D xdg-open-as-default-browser.patch
  D xsane_fix_pdf_floats.patch
  D xsane-desktop.patch
* Fri Jul 21 2017 tchvatal@suse.com
- Add patch to build with lcms2 instead of lcms:
  * xsane-0.999-lcms2.patch
* Tue May  3 2016 joerg.lorenzen@ki.tng.de
- Update to version 0.999:
  + Better preview window size calculation (thanks to
    Nils Phillipsen).
  + Removed null-pointer bug in xsane_update_param (thanks to
    Nils Phillipsen).
  + Manual page bugix.
  + Changed email password storage.
- Fixed no-eula.patch.
* Mon Jan 27 2014 lnussel@suse.de
- fix compiled in location of documentation (bnc#577803)
* Sat Jan 19 2013 lnussel@suse.de
- fix potential memory leak (bnc#542539, xsane-memory-leak.diff)
* Mon Oct 15 2012 pgajdos@suse.com
- fixed build with libpng15
  * libpng15.patch
* Thu Feb 23 2012 coolo@suse.com
- we need libjpeg-devel too
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Wed Dec 22 2010 aj@suse.de
- The manual is in _datadir/sane/xsane/doc, so do not package it
  twice.
* Wed Dec 22 2010 aj@suse.de
- Fix packaging - own directories.
* Sat Nov 20 2010 dimstar@opensuse.org
- Update to version 0.998:
  + bugfix for 16bit png format
  + removed some gtk warnings
  + removed two format string errors
  + corrected some compilation issues
- Rebase no-eula.patch.
- Clean spec file using spec-cleaner.
* Wed Sep 15 2010 aj@suse.de
- Change BuildRequires for sane-backends devel split.
* Tue May 11 2010 lnussel@suse.de
- include html documentation (bnc#577803)
* Thu Nov 26 2009 dimstar@opensuse.org
- Rebase patches to apply with fuzz=0.
* Mon Jul 27 2009 dominique-obs@leuenberger.net
- Update to version 0.997:
  + removed SANE_CAP_ALWAYS_SETTABLE (not SANE1)
  + added test for (opt->size == 0) for SANE_TYPE_STRING in xsane.c
  + in gtk_adjustment_new changed page_size from (min-max)*1e-30 to
    0 because new gtk versions don`t link non zero values for
    spinbuttons
  + added several gdk_drawable_unref(mask)
* Wed Jul  8 2009 lnussel@suse.de
- fix pdf saving in non-POSIX locales
* Wed May  6 2009 sbrabec@suse.cz
- Updated to version 0.996:
  * corrected bug in PDF documents
  * viewer window does not use full screen without window frame for
    large images any more
- Use upstream desktop and icon.
- Use %%find_lang.
* Thu Sep  4 2008 jsmeix@suse.de
- Provide the RPM capability "gimp-2.0-scanner-plugin" which is
  also provided by the sane-frontends RPM so that the gimp RPM
  can recommend "gimp-2.0-scanner-plugin" so that either of xsane
  or sane-frontends are sufficient to be installed
  (see Novell/Suse Bugzilla bnc#422558).
* Tue Mar 11 2008 jsmeix@suse.de
- Enhanced and re-enabled no-eula.patch:
  It suppresses the disclaimer of warranty and liability dialog
  and adds a modification note and adds a openSUSE Bugzilla URL
  to make the change obvious for the user and direct bug reports
  to us (see Novell/Suse Bugzilla bnc#183725).
- xdg-open-as-default-browser.patch sets DEFAULT_BROWSER xdg-open
  to get the right browser launched for KDE and Gnome users to
  show the XSane documentation. Therefore xdg-utils is required.
- remove-non-working-help.patch removes the items in the help
  menue regarding backend documentation because the referred
  files do not exist (dead URLs with "sane-<backend>-doc.html"
  in sane-backends-doc.html).
* Wed Nov 28 2007 jsmeix@suse.de
- Updated to version 0.995:
  Several layout changes.
  Multiple mail receivers are allowed in email mode.
  Scanning and conversion speed is increased.
- Disabled no-eula.patch to be on the safe side because of
  comment 12 in Novell/Suse Bugzilla bnc#183725.
  until there is a final decission regarding the issue.
* Fri Nov  2 2007 ro@suse.de
- Removed liblcms from BuildRequires because liblcms-devel
  requires it via RPM dependency.
* Wed Oct 24 2007 mauro@suse.de
- no-eula.patch suppresses the disclaimer of warranty and
  liability (see Novell/Suse Bugzilla bnc#183725).
* Wed Jul  4 2007 jsmeix@suse.de
- Added liblcms and liblcms-devel to BuildRequires to enable
  LCMS (color management) support.
* Mon Mar  5 2007 jsmeix@suse.de
- Updated to version 0.994 (a bugfix release for 0.993):
  Fixed crash when no ICC/ICM profile was defined.
  Fixed PostScript output which did not work for printing.
* Mon Feb 26 2007 jsmeix@suse.de
- Updated to version 0.993 (this is a beta-test release):
  12 bits/channel support for PostScript.
  Usage of new gtk_file_chooser.
  Added browse function for project directories.
  Correct handling when mail is not accepted by the mailserver.
  A lot of color management improvements (CMS still in
  beta test): Embedded profiles for PostScript and PDF,
  convert to sRGB, convert to working color space.
* Wed Jan 31 2007 jsmeix@suse.de
- Package 'sane' was renamed to 'sane-backends'.
  Adapted it so that it works with 'sane-backends'
* Tue Jan 30 2007 ro@suse.de
- GNOME moved to /usr therefore the GIMP plugin link was
  changed accordingly
* Fri Jan 26 2007 jsmeix@suse.de
- Updated to version 0.992:
  Some bugs and compiler warnings have been fixed.
  New rudimentary color management support.
  This version may crash or produce unexpected results,
  especially with color management enabled.
* Thu Dec  7 2006 jsmeix@suse.de
- Changed /usr/X11R6/bin/xsane to /usr/bin/xsane
  (see Suse bugzilla bnc##224882).
* Sat Oct 28 2006 meissner@suse.de
- buildrequires: libgphoto2-devel
* Tue Sep  5 2006 aj@suse.de
- Cleanup BuildRequires.
* Fri Jul 14 2006 jsmeix@suse.de
- Updated to version 0.991:
  This version contains some bugfixes (in particular for the
  multipage mode which was introduced in version 0.99).
- Removed obsolete BuildRequires for hp-officeJet.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 10 2006 jsmeix@suse.de
- Updated to version 0.99
* Tue Jan  3 2006 jsmeix@suse.de
- Updated to version 0.98b
* Wed Nov 23 2005 jsmeix@suse.de
- Updated to version 0.98a
* Mon Jan 24 2005 jsmeix@suse.de
- Updated to version 0.97
  This version contains some bugfixes.
* Mon Nov 22 2004 jsmeix@suse.de
- Added scanner_32x32.png as icon file for xsane.desktop.
* Wed Nov 17 2004 jsmeix@suse.de
- Updated to version 0.96
  This version contains several bugfixes and improvements,
  especially for the fax mode and the email mode.
* Mon Aug 16 2004 jsmeix@suse.de
- Updated to version 0.95 (has gimp-2.0.x support included)
* Wed Jul 21 2004 jsmeix@suse.de
- Added libieee1284 as needed for build because sane is needed
  to build xsane and as sane has now libieee1284 support it is
  also needed to build xsane.
* Tue Mar 23 2004 jsmeix@suse.de
- gimp plugins are now in .../2.0/...
* Mon Feb 23 2004 ro@suse.de
- update to 0.92
- build with gtk2 stuff
- added patch from debian maintainer to support gimp2
- gettext stuff doesn't work yet
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Nov 10 2003 ro@suse.de
- use net-snmp instead of ucdsnmp
* Fri Aug 15 2003 adrian@suse.de
- add desktop file
* Tue Jul 29 2003 coolo@suse.de
- use %%find_lang
* Mon Jun 30 2003 freitag@suse.de
- fixed 64bit libpath problem with gimp plugin
* Fri Jun  6 2003 freitag@suse.de
- update to version 0.91
* Mon Feb  3 2003 freitag@suse.de
- added libtiff for tiff support again.
* Sun Feb  2 2003 ro@suse.de
- blow up neededforbuild again to make it build
* Fri Jan 24 2003 freitag@suse.de
- update to version 0.90
  cleaned up neededforbuild a bit, removed gimp etc.
  added libgphoto, now required for SANE
* Thu Oct 31 2002 freitag@suse.de
- update to version 0.89
* Mon Oct 21 2002 ro@suse.de
- added pkgconfig and libusb to neededforbuild
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Wed Jul 17 2002 freitag@suse.de
- update to version 0.87
* Wed May  8 2002 freitag@suse.de
- update to version 0.86
  small bugfixing and functional updates
* Wed Apr 24 2002 freitag@suse.de
- update to v. 0.85
  changed default help browser to konqueror since that is the
  SuSE default browser.
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 24 2002 egmont@suselinux.hu
- fixed URL
* Thu Jan 10 2002 freitag@suse.de
- update to v. 0.83
* Mon Nov 12 2001 freitag@suse.de
- update to version 0.80, which provides a build-in viewer to see
  the scan results immediately, some bugfixes and new and
  updated translations: cs, de, fr, ja, ru, tr
* Sat Sep 15 2001 kukuk@suse.de
- Remove netscape from requires
* Fri Aug 31 2001 ro@suse.de
- added <hp-officeJet> to neededforbuild (for sane)
* Wed Aug 22 2001 freitag@suse.de
- update to version 0.79, which include:
  * (still experimental) email functionality improved
  * preview improvement
  * medium selection for negatives
  * security enhancement when xsane is running with suid=root
* Fri Jun 29 2001 freitag@suse.de
- update to version 0.78
* Tue Apr 24 2001 egger@suse.de
- Updated to version 0.75.
- Use BuildRooting
- Use better paths for data.
- Should fix bug 7088.
* Mon Apr  2 2001 freitag@suse.de
- update to version 0.74, source in bzip2-format.
* Mon Mar  5 2001 freitag@suse.de
- update to version 0.72
* Thu Jan 18 2001 freitag@suse.de
- update to version 0.70 to fix a bug with gimp plugin mode.
* Mon Dec 18 2000 freitag@suse.de
- update to version 0.67
* Fri Dec  8 2000 freitag@suse.de
- update to version 0.64
* Mon Nov  6 2000 freitag@suse.de
- changed License/Copyright in spec-File
* Thu Nov  2 2000 freitag@suse.de
- update to version 0.62
  neededforbuild needs gimp-devel, not gimp-dev
* Wed Nov  1 2000 egger@suse.de
- Updated specfile to new long packagenames.
- Reworked specfile.
- Probably needs some more work; I'm taking care of that.
* Mon Sep 25 2000 ro@suse.de
- make it compile
* Tue Sep 19 2000 egger@suse.de
- Use -p for makedir.
- Buildproofed on i386.
* Mon Sep  4 2000 egger@suse.de
- update to version 0.61
* Wed Jun  7 2000 freitag@suse.de
- update to version 0.57
* Sat Mar  4 2000 ro@suse.de
- removed libgimp from neededforbuild
* Mon Feb 28 2000 freitag@suse.de
- inserted group tag
* Mon Feb 14 2000 freitag@suse.de
- update to version 0.55
* Mon Jan 10 2000 freitag@suse.de
- update to version 0.49
* Tue Oct 26 1999 freitag@suse.de
- initial verison 0.40
